---
name: Feature request
about: Suggest an idea for Speckle!
title: ''
labels: enhancement, question
assignees: ''
---

<!---

Provide a short summary in the Title above. Examples of good Issue titles:

* "Enhancement: Connector for Minecraft"
* "Enhancement: Web viewer should support tesseracts"

-->

## Prerequisites

<!---

Please answer the following questions before submitting an issue.

-->

- [ ] I read the [contribution guidelines](https://github.com/specklesystems/speckle-server/blob/main/CONTRIBUTING.md)
- [ ] I checked the [documentation](https://speckle.guide/) and found no answer.
- [ ] I checked [existing issues](../issues?q=is%3Aissue) and found no similar issue. <!-- If you do find an existing issue, please show your support by liking it :+1: instead of creating a new issue -->
- [ ] I checked the [community forum](https://speckle.community/) for related discussions and found no answer.
- [ ] I'm requesting the feature to the correct repository (see also [speckle-server](https://github.com/specklesystems/speckle-server), [speckle-sharp](https://github.com/specklesystems/speckle-sharp), [specklepy](https://github.com/specklesystems/specklepy), [speckle-docs](https://github.com/specklesystems/speckle-docs), and [others](https://github.com/orgs/specklesystems/repositories))

## What package are you referring to?

<!---
Is it related to the server (backend) only, or does this feature request relate to the frontend, viewer, objectloader or any other package?
-->

## Is your feature request related to a problem? Please describe.

<!---
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]
-->

## Describe the solution you'd like

<!---
A clear and concise description of what you want to happen.
-->

## Describe alternatives you've considered

<!---
A clear and concise description of any alternative solutions or features you've considered.
-->

## Additional context

<!---
Add any other context or screenshots about the feature request here.

Have you seen this feature implemented in any other software?  Can you provide screenshots or links to video or documentation?
What works well about these existing features in other software?  What doesn't work well?
-->

## Related issues or community discussions

<!---
Is this feature request related to (but sufficiently distinct from) any existing issues?
Does this feature request require other features to be available beforehand?
Has this feature been discussed in the community forum, please link here? https://speckle.community/
-->
